==> bouml_2.7.4.tar.gz: bouml_2.7.4/src/JavaGenerator/UmlOperation.h <==
// *************************************************************************
//
// Copyright (C) 2004,2005 Bruno PAGES  All rights reserved.
//
// This file is part of the BOUML Uml Toolkit.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// e-mail : bouml@free.fr
// home   : http://bouml.free.fr
//
// *************************************************************************

#ifndef UMLOPERATION_H
#define UMLOPERATION_H

#include "UmlBaseOperation.h"

class UmlOperation : public UmlBaseOperation {
  public:
    UmlOperation(void * id, const QCString & n)
      : UmlBaseOperation(id, n) {};
  
    //virtual void compute_dependency(QList<JavaRefType> & dependency, QCString cl_stereotype);
    virtual void generate(QTextOStream & f, const QCString & cl_stereotype,
			  QCString indent);
    virtual void generate_enum_item(QTextOStream &, int &, const QCString &, QCString);
    virtual void generate_enum_case(QTextOStream &, QCString);
    
    QCString compute_name();
};

#endif

==> bouml_2.15.4.tar.gz: bouml_2.15.4/src/JavaGenerator/UmlOperation.h <==
// *************************************************************************
//
// Copyright (C) 2004-2006 Bruno PAGES  All rights reserved.
// Copyright (C) 2004-2006 Bruno PAGES  All rights reserved.
//
// This file is part of the BOUML Uml Toolkit.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// e-mail : bouml@free.fr
// home   : http://bouml.free.fr
//
// *************************************************************************

#ifndef UMLOPERATION_H
#define UMLOPERATION_H

#include "UmlBaseOperation.h"

class UmlOperation : public UmlBaseOperation {
  public:
    UmlOperation(void * id, const QCString & n)
      : UmlBaseOperation(id, n) {};
  
    //virtual void compute_dependency(QList<JavaRefType> & dependency, QCString cl_stereotype);
    virtual void generate(QTextOStream & f, const QCString & cl_stereotype,
			  QCString indent);
    virtual void generate_enum_pattern_item(QTextOStream &, int &, const QCString &, QCString);
    virtual void generate_enum_pattern_case(QTextOStream &, QCString);
    virtual void generate_enum_member(QTextOStream &, QCString);
    
    QCString compute_name();
};

#endif
